@@ -15,14 +15,16 @@ class Reader(ABC):
 
 
 class BigQueryReader(Reader):
-    def __init__(self, json_credentials_path=None):
+    def __init__(self, json_credentials_path=None, credentials=None): # pragma: no cover
+        if json_credentials_path and credentials:
+            raise Exception('Only specify json_credentials_path OR credentials, specifying both is not allowed')
         if json_credentials_path:
             self.client = bigquery.Client.from_service_account_json(json_credentials_path=json_credentials_path)
+        elif credentials:
+            self.client = bigquery.Client(credentials=credentials)
         else:
             self.client = bigquery.Client()
 
     def execute(self, query) -> List[Dict[str, Any]]:
         query_job = self.client.query(query)
         return [{item[0]:item[1] for item in row.items()} for row in query_job]
-
-
